==> haskell-hie-bios-0.12.0-151-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hie-bios.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hie-bios
version:              0.12.0
visibility:           public
id:                   hie-bios-0.12.0-FNEim36epU8Dn9Th1xNmRS
key:                  hie-bios-0.12.0-FNEim36epU8Dn9Th1xNmRS
license:              BSD-3-Clause
maintainer:           Matthew Pickering <matthewtpickering@gmail.com>
author:               Matthew Pickering <matthewtpickering@gmail.com>
homepage:             https://github.com/mpickering/hie-bios
synopsis:             Set up a GHC API session
description:
    Set up a GHC API session and obtain flags required to compile a source file

category:             Development
abi:                  2b7f86e528ae19053b16893552c57431
exposed:              True
exposed-modules:
    HIE.Bios HIE.Bios.Config HIE.Bios.Config.YAML HIE.Bios.Cradle
    HIE.Bios.Environment HIE.Bios.Flags HIE.Bios.Ghc.Api
    HIE.Bios.Ghc.Check HIE.Bios.Ghc.Doc HIE.Bios.Ghc.Gap
    HIE.Bios.Ghc.Load HIE.Bios.Ghc.Logger HIE.Bios.Internal.Debug
    HIE.Bios.Types HIE.Bios.Wrappers

hidden-modules:       Paths_hie_bios
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hie-bios-0.12.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hie-bios-0.12.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hie-bios-0.12.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hie-bios
hs-libraries:         HShie-bios-0.12.0-FNEim36epU8Dn9Th1xNmRS
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1
    base16-bytestring-1.0.2.0-ARBAmNNbyxLEDoUwDjra0R
    bytestring-0.11.5.3 co-log-core-0.3.2.5-3ZAPJG8B8UQLXQ3UK4qwOj
    conduit-1.3.6.1-5afbFXdQmpuHK8N5OCErlh
    conduit-extra-1.3.8-Dg42smPzbiF4Nemzj9bTg6
    cryptohash-sha1-0.11.101.0-I0vIPZWrlt0Gys06a7iUtx deepseq-1.4.8.1
    directory-1.3.8.5 exceptions-0.10.7
    extra-1.7.16-IkudFHstV64EKMSGT8IWWb
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    ghc-9.6.6 prettyprinter-1.7.1-BsaWeUw0po1KNye7GKTBJ
    template-haskell-2.20.0.0 temporary-1.3-29RL4tTXoFB72QSCtJnhBC
    text-2.0.2 time-1.12.2 transformers-0.6.1.0
    unix-compat-0.7.4.1-4zbVOVPfIKMI5a8vIMtFDq
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    yaml-0.11.11.2-HJgRwey6BMIIq0hOFQKRBa

haddock-interfaces:   /usr/share/doc/haskell-hie-bios/html/hie-bios.haddock
haddock-html:         /usr/share/doc/haskell-hie-bios/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hie-bios-0.12.0-153-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hie-bios.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hie-bios
version:              0.12.0
visibility:           public
id:                   hie-bios-0.12.0-D5SlUNhEiEdEEQ41lCtVRh
key:                  hie-bios-0.12.0-D5SlUNhEiEdEEQ41lCtVRh
license:              BSD-3-Clause
maintainer:           Matthew Pickering <matthewtpickering@gmail.com>
author:               Matthew Pickering <matthewtpickering@gmail.com>
homepage:             https://github.com/mpickering/hie-bios
synopsis:             Set up a GHC API session
description:
    Set up a GHC API session and obtain flags required to compile a source file

category:             Development
abi:                  aee542c8b14d1592b6f7557b03c0bd9f
exposed:              True
exposed-modules:
    HIE.Bios HIE.Bios.Config HIE.Bios.Config.YAML HIE.Bios.Cradle
    HIE.Bios.Environment HIE.Bios.Flags HIE.Bios.Ghc.Api
    HIE.Bios.Ghc.Check HIE.Bios.Ghc.Doc HIE.Bios.Ghc.Gap
    HIE.Bios.Ghc.Load HIE.Bios.Ghc.Logger HIE.Bios.Internal.Debug
    HIE.Bios.Types HIE.Bios.Wrappers

hidden-modules:       Paths_hie_bios
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hie-bios-0.12.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hie-bios-0.12.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hie-bios-0.12.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hie-bios
hs-libraries:         HShie-bios-0.12.0-D5SlUNhEiEdEEQ41lCtVRh
depends:
    aeson-2.2.0.0-Hqy1Zqe0ZE81dk2L20icmH base-4.18.2.1
    base16-bytestring-1.0.2.0-6gPusxqn90AJxFEjBUebK6
    bytestring-0.11.5.3 co-log-core-0.3.2.5-E4gc6H4PEp9IHp9m40mldi
    conduit-1.3.6.1-CwUx671uWmDAcHwxI0YYDy
    conduit-extra-1.3.8-GHF5wYhQp30HUaLAtCbs0G
    cryptohash-sha1-0.11.101.0-1heoWn4oR2U4lk61vABA6p deepseq-1.4.8.1
    directory-1.3.8.5 exceptions-0.10.7
    extra-1.7.16-1R70WzmZutyIjhcnCYje37
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    ghc-9.6.6 prettyprinter-1.7.1-LgLGkLn2CvpBXnv6jAGI5w
    template-haskell-2.20.0.0 temporary-1.3-GTgxkhi2PMM37jgbXakJ3s
    text-2.0.2 time-1.12.2 transformers-0.6.1.0
    unix-compat-0.7.4.1-A9X47MkwTFf6xepaAigQ6V
    unordered-containers-0.2.20.1-1hrud2F05KV7Rz7RsKTZ5O
    yaml-0.11.11.2-7sI7sa5XZN9728orpxXF0B

haddock-interfaces:   /usr/share/doc/haskell-hie-bios/html/hie-bios.haddock
haddock-html:         /usr/share/doc/haskell-hie-bios/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
